==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/ru/messagestyles.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
<context>
    <name>MessageStyles</name>
    <message>
        <source>Message Styles</source>
        <translation>Стили сообщений</translation>
    </message>
    <message>
        <source>d MMM yyyy hh:mm</source>
        <translation>d MMM yyyy hh:mm</translation>
    </message>
    <message>
        <source>d MMM hh:mm</source>
        <translation></translation>
    </message>
    <message>
        <source>hh:mm:ss</source>
        <translation>hh:mm:ss</translation>
    </message>
    <message>
        <source>Message Styles Manager</source>
        <translation>Диспетчер стилей сообщений</translation>
    </message>
    <message>
        <source>Allows to use different styles to display messages</source>
        <translation>Позволяет использовать различные стили для отображения сообщений</translation>
    </message>
</context>
<context>
    <name>StyleOptionsWidget</name>
    <message>
        <source>Chat</source>
        <translation>Чат</translation>
    </message>
    <message>
        <source>Conference</source>
        <translation>Конференция</translation>
    </message>
    <message>
        <source>The message with a error code %1 is received</source>
        <translation>Получено сообщение с кодом ошибки №%1</translation>
    </message>
    <message>
        <source>Error description</source>
        <translation>Описание ошибки</translation>
    </message>
    <message>
        <source>Subject: Message subject</source>
        <translation>Тема: Тема сообщения</translation>
    </message>
    <message>
        <source>Message body line 1</source>
        <translation>Тело сообщения, строка 1</translation>
    </message>
    <message>
        <source>Message body line 2</source>
        <translation>Тело сообщения, строка 2</translation>
    </message>
    <message>
        <source>Incoming history message</source>
        <translation>Входящее старое сообщение</translation>
    </message>
    <message>
        <source>Incoming history consecutive message</source>
        <translation>Входящее старое последовательное сообщение</translation>
    </message>
    <message>
        <source>Incoming status message</source>
        <translation>Входящее статус-сообщений</translation>
    </message>
    <message>
        <source>Outgoing history message</source>
        <translation>Исходящее старое сообщение</translation>
    </message>
    <message>
        <source>Outgoing status message</source>
        <translation>Исходящее статус-сообщение</translation>
    </message>
    <message>
        <source>Groupchat topic</source>
        <translation>Тема конференции</translation>
    </message>
    <message>
        <source>Incoming message</source>
        <translation>Входящее сообщение</translation>
    </message>
    <message>
        <source>Incoming event</source>
        <translation>Входящее событие</translation>
    </message>
    <message>
        <source>Incoming notification</source>
        <translation>Входящее уведомление</translation>
    </message>
    <message>
        <source>Incoming mention message</source>
        <translation>Входящее сообщение с обращением</translation>
    </message>
    <message>
        <source>Outgoing message</source>
        <translation>Исходящее сообщение</translation>
    </message>
    <message>
        <source>Outgoing consecutive message</source>
        <translation>Исходящее последовательное сообщение</translation>
    </message>
    <message>
        <source>Receiver</source>
        <translation>Получатель</translation>
    </message>
    <message>
        <source>Sender</source>
        <translation>Отправитель</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Сообщение</translation>
    </message>
    <message>
        <source>Headline</source>
        <translation>Новость</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
</context>
<context>
    <name>StyleOptionsWidgetClass</name>
    <message>
        <source>Message type:</source>
        <translation>Тип сообщения:</translation>
    </message>
    <message>
        <source>Style engine:</source>
        <translation>Тип стиля:</translation>
    </message>
</context>
</TS>

==> vacuum-1.2.4.tar.xz: vacuum-1.2.4/src/translations/ru/messagestyles.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
<context>
    <name>MessageStyles</name>
    <message>
        <source>Message Styles</source>
        <translation>Стили сообщений</translation>
    </message>
    <message>
        <source>d MMM yyyy hh:mm</source>
        <translation>d MMM yyyy hh:mm</translation>
    </message>
    <message>
        <source>d MMM hh:mm</source>
        <translation></translation>
    </message>
    <message>
        <source>hh:mm:ss</source>
        <translation>hh:mm:ss</translation>
    </message>
    <message>
        <source>Message Styles Manager</source>
        <translation>Диспетчер стилей сообщений</translation>
    </message>
    <message>
        <source>Allows to use different styles to display messages</source>
        <translation>Позволяет использовать различные стили для отображения сообщений</translation>
    </message>
    <message>
        <source>Show date separators in chat window</source>
        <translation>Показывать разделители дат в окне чата</translation>
    </message>
    <message>
        <source>January</source>
        <translation>Января</translation>
    </message>
    <message>
        <source>February</source>
        <translation>Февраля</translation>
    </message>
    <message>
        <source>March</source>
        <translation>Марта</translation>
    </message>
    <message>
        <source>April</source>
        <translation>Апреля</translation>
    </message>
    <message>
        <source>May</source>
        <translation>Мая</translation>
    </message>
    <message>
        <source>June</source>
        <translation>Июня</translation>
    </message>
    <message>
        <source>July</source>
        <translation>Июля</translation>
    </message>
    <message>
        <source>August</source>
        <translation>Августа</translation>
    </message>
    <message>
        <source>September</source>
        <translation>Сентября</translation>
    </message>
    <message>
        <source>October</source>
        <translation>Октября</translation>
    </message>
    <message>
        <source>November</source>
        <translation>Ноября</translation>
    </message>
    <message>
        <source>December</source>
        <translation>Декабря</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Понедельник</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Вторник</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Среда</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Четверг</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Пятница</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Суббота</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Воскресенье</translation>
    </message>
    <message>
        <source>%1, %2 dd</source>
        <translation>%1, dd %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Сегодня</translation>
    </message>
    <message>
        <source>%1, %2 dd, yyyy</source>
        <translation>%1, dd %2, yyyy</translation>
    </message>
</context>
<context>
    <name>StyleOptionsWidget</name>
    <message>
        <source>Chat</source>
        <translation>Чат</translation>
    </message>
    <message>
        <source>Conference</source>
        <translation>Конференция</translation>
    </message>
    <message>
        <source>The message with a error code %1 is received</source>
        <translation>Получено сообщение с кодом ошибки №%1</translation>
    </message>
    <message>
        <source>Error description</source>
        <translation>Описание ошибки</translation>
    </message>
    <message>
        <source>Subject: Message subject</source>
        <translation>Тема: Тема сообщения</translation>
    </message>
    <message>
        <source>Message body line 1</source>
        <translation>Тело сообщения, строка 1</translation>
    </message>
    <message>
        <source>Message body line 2</source>
        <translation>Тело сообщения, строка 2</translation>
    </message>
    <message>
        <source>Incoming history message</source>
        <translation>Входящее старое сообщение</translation>
    </message>
    <message>
        <source>Incoming history consecutive message</source>
        <translation>Входящее старое последовательное сообщение</translation>
    </message>
    <message>
        <source>Incoming status message</source>
        <translation>Входящее статус-сообщение</translation>
    </message>
    <message>
        <source>Outgoing history message</source>
        <translation>Исходящее старое сообщение</translation>
    </message>
    <message>
        <source>Outgoing status message</source>
        <translation>Исходящее статус-сообщение</translation>
    </message>
    <message>
        <source>Groupchat topic</source>
        <translation>Тема конференции</translation>
    </message>
    <message>
        <source>Incoming message</source>
        <translation>Входящее сообщение</translation>
    </message>
    <message>
        <source>Incoming event</source>
        <translation>Входящее событие</translation>
    </message>
    <message>
        <source>Incoming notification</source>
        <translation>Входящее уведомление</translation>
    </message>
    <message>
        <source>Incoming mention message</source>
        <translation>Входящее сообщение с обращением</translation>
    </message>
    <message>
        <source>Outgoing message</source>
        <translation>Исходящее сообщение</translation>
    </message>
    <message>
        <source>Outgoing consecutive message</source>
        <translation>Исходящее последовательное сообщение</translation>
    </message>
    <message>
        <source>Receiver</source>
        <translation>Получатель</translation>
    </message>
    <message>
        <source>Sender</source>
        <translation>Отправитель</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Сообщение</translation>
    </message>
    <message>
        <source>Headline</source>
        <translation>Новость</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
</context>
<context>
    <name>StyleOptionsWidgetClass</name>
    <message>
        <source>Message type:</source>
        <translation>Тип сообщения:</translation>
    </message>
    <message>
        <source>Style engine:</source>
        <translation>Тип стиля:</translation>
    </message>
</context>
</TS>
